@@ -1,14 +1,13 @@
-package FUNCS;
-
+package FUNCS; 
 use strict;
 use warnings;
 use Class::Struct;
 
 our $VERSION = "1.00";
 
-my $easel        = "~/src/hmmer/hmmer/easel/miniapps";
-my $esl_reformat = "$easel/esl-reformat";
-my $esl_afetch   = "$easel/esl-afetch";
+my $esl_reformat = "esl-reformat";
+my $esl_afetch   = "esl-afetch";
+
 
 sub afa2sto {
     my ($root, $file) = @_;
@@ -17,6 +16,13 @@ sub afa2sto {
     return $stof;
 }
 
+sub sto2fa {
+    my ($root, $file) = @_;
+    my $fastaf = "$root.fa";
+    system("$esl_reformat fasta $file > $fastaf\n");
+    return $fastaf;
+}
+
 sub are_disjoint {
     my ($asq1, $asq2) = @_;
     my $disjoint = 1;
@@ -91,7 +97,8 @@ sub calculate_averages {
         $mean /= $number;
 
         $std -= $mean*$mean*$number;
-        $std /= ($number-1);
+        #$std /= ($number-1);
+        $std /= ($number);
         if ($std < 0. && $std> -0.00001) { $std = 0.0; }
         $std  = sqrt($std);
     }
@@ -383,15 +390,23 @@ sub gnuplot_ave_histo_with_dots {
 
 sub gnuplot_define_styles {
     my ($gp) = @_;
-    print $gp "set style line 1   lt 1 lc rgb 'black'   pt 1 ps 0.5 lw 1\n";
-    print $gp "set style line 2   lt 1 lc rgb 'brown'   pt 1 ps 0.6 lw 1\n";
-    print $gp "set style line 3   lt 1 lc rgb 'grey'    pt 1 ps 0.5 lw 1\n";
-    print $gp "set style line 4   lt 1 lc rgb 'cyan'    pt 1 ps 0.5 lw 3\n";
-    print $gp "set style line 7   lt 1 lc rgb 'red'     pt 1 ps 0.5 lw 3\n";
-    print $gp "set style line 5   lt 1 lc rgb 'purple'  pt 1 ps 0.5 lw 3\n";
-    print $gp "set style line 6   lt 1 lc rgb 'orange'  pt 1 ps 0.5 lw 3\n";
-    print $gp "set style line 8   lt 1 lc rgb 'blue'    pt 1 ps 0.6 lw 3\n";
-    print $gp "set style line 9   lt 2 lc rgb 'magenta' pt 1 ps 0.5 lw 3\n";
+    print $gp "set style line 8888  lt 1 lc rgb 'black'   pt 1 ps 0.5 lw 1\n";
+    print $gp "set style line 222   lt 1 lc rgb 'green'   pt 1 ps 0.5 lw 4\n";
+    print $gp "set style line 333   lt 1 lc rgb '#5D5C74'    pt 1 ps 0.5 lw 4\n";
+    print $gp "set style line 444   lt 1 lc rgb '#0CA74A'    pt 1 ps 0.5 lw 4\n";
+    print $gp "set style line 555   lt 1 lc rgb '#8CCFB4'    pt 1 ps 0.5 lw 4\n";
+    print $gp "set style line 666   lt 1 lc rgb '#C15742'    pt 1 ps 0.5 lw 4\n";
+    print $gp "set style line 777   lt 1 lc rgb '#FAA51A'    pt 1 ps 0.5 lw 4\n";
+   
+    print $gp "set style line 1   lt 1 lc rgb 'black'   pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 2   lt 1 lc rgb 'green'   pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 3   lt 1 lc rgb 'grey'    pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 4   lt 1 lc rgb 'cyan'    pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 7   lt 1 lc rgb 'red'     pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 5   lt 1 lc rgb 'purple'  pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 6   lt 1 lc rgb 'orange'  pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 8   lt 1 lc rgb 'blue'    pt 7 ps 0.5 lw 6\n";
+    print $gp "set style line 9   lt 2 lc rgb 'magenta' pt 7 ps 0.5 lw 6\n";
    
     print $gp "set style line 88   lt 1 lc rgb 'cyan'   pt 7 pi -1  ps 1.0 lw 2\nset pointintervalbox 1\n";
 
@@ -1916,58 +1931,77 @@ sub parse_sqfile {
 }
 
 sub parse_stofile {
-    my ($sqfile, $ret_nsq, $name_ref, $sq_ref, $ret_ss, $ct_ref, $ret_rfsq) = @_;
+    my ($sqfile, $ret_nsq, $name_ref, $sq_ref, $ret_ss, $ct_ref, $ret_rfsq, $which) = @_;
 
+    my $nali = 0;
     my $nsq = 0;
     my $sq = "";
     my $ss = "";
     my $name = "";
     my $rfsq = "";
-
+    my $thisone = 0;
+    
     my $b = 0;
+    my $nsq_prv = 0;
     open(FILE, "$sqfile") || die;
     while (<FILE>) {
 	if (/# STO/) {
+	    $nali ++;
+	    if ($which > 0 && $nali > $which) { last; }
 	}
 	elsif (/#=GC\s+SS_cons\s+(\S+)\s*$/) {
-	    $ss .= "$1";
+	    if ($which == 0 || $nali == $which) { $ss .= "$1"; }
 	}
 	elsif (/#=GC\s+RF\s+(\S+)\s*$/) {
-	    $rfsq .= "$1";
+	    if ($which == 0 || $nali == $which) { $rfsq .= "$1"; }
 	}
 	elsif (/^#/) {
 	}
 	elsif (/^$/) {
-	    $b ++;
-	    $nsq = 0;
+	    if ($which == 0 || $nali == $which) { 
+		$b ++;
+		$nsq_prv = $nsq;
+		$nsq = 0;
+	    }
 	}
 	elsif (/^([^#]\S+)\s+(\S+)\s*$/) {
-	    $name_ref->[$nsq]  = $1;
-	    $sq_ref->[$nsq]   .= "$2";
-	    $nsq ++;
-	}
-	elsif ($nsq > 0 && /^(\S+)\s+(\S+)\s*$/) {
 	    my $name  = $1;
 	    my $sq    = $2;
-	    
-	    if ($name =~ /^$name_ref->[$nsq]$/) {
-		$sq_ref->[$nsq] .= "$sq";
+	    if ($which == 0 || $nali == $which) {
+		$name_ref->[$nsq]  = $name;
+		$sq_ref->[$nsq]   .= "$sq";
 		$nsq ++;
 	    }
-	    else { print "bad sq $name | $name_ref->[$nsq]\n"; die; }
 	}
+	elsif ($nsq > 0 && /^([^#]\S+)\s+(\S+)\s*$/) {
+	    my $name  = $1;
+	    my $sq    = $2;
+	    if ($which == 0 || $nali == $which) { 
+		if ($name =~ /^$name_ref->[$nsq]$/) {
+		    $sq_ref->[$nsq] .= "$sq";
+		    $nsq ++;
+		}
+		else { print "bad sq $name | $name_ref->[$nsq]\n"; die; }
+	    }
+	}
+	elsif (/\/\//) {
+	    $b = 0;
+	    $$ret_ss   = $ss;
+	    $$ret_rfsq = $rfsq;
+	    $$ret_nsq  = $nsq;
+	}
+
     }
     close(FILE);
-
+    if ($b > 1 && $nsq != $nsq_prv && $nsq_prv > 0) { print "$sqfile\nparse_stofile error in block $b: nsq $nsq nsq_prv $nsq_prv\n"; die; }
+    
     ss2ct($ss, $ct_ref);
 
-    $$ret_ss   = $ss;
-    $$ret_rfsq = $rfsq;
-    $$ret_nsq  = $nsq;
  
-    return length($ss);
+    return length($sq_ref->[0]);
 }
 
+
 sub ss2ct {
     my ($ss, $ct_ref) = @_;
 
@@ -2802,23 +2836,35 @@ sub write_ave_histogram {
 
 sub write_histogram {
     
-    my ($N, $k, $shift, $histo_ref, $scale, $hfile, $expo) = @_;
+    my ($N, $k, $shift, $histo_ref, $scale, $hfile, $expo, $documulative) = @_;
     
     my $dim = $N * $k;
     
     open(HIS, ">$hfile");
-    
+
+    my $cum = 0;
     for (my $i=0; $i<=$dim; $i++) { 
 	my $len = ($i)/$k - $shift;
-	if ($histo_ref->[$i] >= 0) { 
-	    if ($expo) { printf HIS "%g\t%f\n", exp($len), $histo_ref->[$i]*$scale; }
-	    else       { printf HIS "%f\t%f\n", $len, $histo_ref->[$i]*$scale; }
+	if ($histo_ref->[$i] > 0) {
+	    my $hval = $histo_ref->[$i]*$scale;
+	    $cum += $hval;
+
+	    if ($documulative) {
+		if ($expo) { printf HIS "%g\t%f\t%f\n", exp($len), $hval, $cum; }
+		else       { printf HIS "%f\t%f\t%f\n", $len,      $hval, $cum; }
+	    }
+	    else {
+		if ($expo) { printf HIS "%g\t%f\n", exp($len), $hval; }
+		else       { printf HIS "%f\t%f\n", $len,      $hval; }
+	    }
+	   
 	}
     }
     
     close (HIS);
 }
 
+
 sub write_histogram_piece {
     
     my ($N, $k, $shift, $histo_ref, $expo, $from, $to) = @_;
@@ -2877,18 +2923,19 @@ sub write_species_file {
 
 sub write_stofile {
 
-    my ($stofile, $nasq, $asq_ref, $asqname_ref, $ss, $useme_ref) = @_;
+    my ($stofile, $nasq, $asq_ref, $asqname_ref, $ss, $useme_ref, $stoname, $append) = @_;
 
     my $id = $stofile;
     if ($id =~ /\/([^\/]+)$/) { $id = $1; }
     if ($id =~ /(\S+).sto/)   { $id = $1; }
+    if ($stoname) { $id .= ".$stoname"; }
     
     my $name;
     my $coords;
     my $block = 180;
     
     print "\nSTOFILE: $stofile\n";
-    open (STO, ">$stofile") || die;
+    if ($append) { open (STO, ">>$stofile") || die; } else { open (STO, ">$stofile") || die; }
     printf STO "\# STOCKHOLM 1.0\n";
     printf STO "\#=GF ID %s\n", $id;
 
